@@ -23,10 +23,11 @@
 #include <goffice/graph/gog-graph.h>
 #include <goffice/graph/gog-graph-impl.h>
 #include <goffice/graph/gog-view.h>
+#include <goffice/math/go-math.h>
 #include <goffice/utils/go-units.h>
+#include <goffice/utils/go-cairo.h>
 #include <goffice/utils/go-color.h>
 #include <goffice/utils/go-font.h>
-#include <goffice/utils/go-math.h>
 #include <goffice/utils/go-marker.h>
 
 #include <gsf/gsf.h>
@@ -57,9 +58,7 @@ enum {
 	RENDERER_PROP_0,
 	RENDERER_PROP_MODEL,
 	RENDERER_PROP_VIEW,
-	RENDERER_PROP_ZOOM,
-	RENDERER_PROP_CAIRO,
-	RENDERER_PROP_IS_VECTOR
+	RENDERER_PROP_ZOOM
 };
 enum {
 	RENDERER_SIGNAL_REQUEST_UPDATE,
@@ -75,7 +74,6 @@ struct _GogRenderer {
 	GogGraph *model;
 	GogView	 *view;
 	float	  scale, scale_x, scale_y;
-	float	  zoom;
 
 	GClosure *font_watcher;
 	gboolean  needs_update;
@@ -94,6 +92,8 @@ struct _GogRenderer {
 	gboolean	 is_vector;
 
 	cairo_t		*cairo;
+	cairo_surface_t *cairo_surface;
+
 	GdkPixbuf 	*pixbuf;
 
 	gboolean	 marker_as_surface;
@@ -113,11 +113,6 @@ typedef struct {
 
 #define GRC_LINEAR_SCALE(w,scale) (go_sub_epsilon (w) <= 0.0 ? GOG_RENDERER_HAIRLINE_WIDTH_PTS : w) * scale
 
-/* This is a workaround for a cairo bug, due to its internal
- * handling of coordinates (16.16 fixed point). */
-#define GO_CAIRO_CLAMP(x) CLAMP((x),-15000,15000)
-#define GO_CAIRO_CLAMP_SNAP(x,even) GO_CAIRO_CLAMP(even ? floor (x + .5):floor (x) + .5)
-
 static void
 grc_path_raw (cairo_t *cr, ArtVpath *vpath, ArtBpath *bpath)
 {
@@ -339,98 +334,23 @@ emit_outline (GogRenderer *rend, gboolean preserve, GOPathOptions options)
 static void
 emit_fill (GogRenderer *rend, gboolean preserve)
 {
-	struct { unsigned x0i, y0i, x1i, y1i; } const grad_i[GO_GRADIENT_MAX] = {
-		{0, 0, 0, 1},
-		{0, 1, 0, 0},
-		{0, 0, 0, 2},
-		{0, 2, 0, 1},
-		{0, 0, 1, 0},
-		{1, 0, 0, 0},
-		{0, 0, 2, 0},
-		{2, 0, 1, 0},
-		{0, 0, 1, 1},
-		{1, 1, 0, 0},
-		{0, 0, 2, 2},
-		{2, 2, 1, 1},
-		{1, 0, 0, 1},
-		{0, 1, 1, 0},
-		{1, 0, 2, 2},
-		{2, 2, 0, 1}
-	};
-
 	GogStyle const *style = rend->cur_style;
 	cairo_t *cr = rend->cairo;
 	cairo_pattern_t *cr_pattern = NULL;
-	cairo_matrix_t cr_matrix;
-	double x[3], y[3];
-	int w, h;
 
-	switch (style->fill.type) {
-		case GOG_FILL_STYLE_NONE:
-			if (!preserve)
-				cairo_new_path (cr);
-			return;
-			break;
-
-		case GOG_FILL_STYLE_PATTERN:
-			cr_pattern = go_pattern_create_cairo_pattern (&style->fill.pattern, cr);
-			cairo_set_source (cr, cr_pattern);
-			break;
-
-		case GOG_FILL_STYLE_GRADIENT:
-			cairo_fill_extents (cr, &x[0], &y[0], &x[1], &y[1]);
-			x[2] = (x[1] - x[0]) / 2.0 + x[1];
-			y[2] = (y[1] - y[0]) / 2.0 + y[1];
-			cr_pattern = cairo_pattern_create_linear (
-				x[grad_i[style->fill.gradient.dir].x0i],
-				y[grad_i[style->fill.gradient.dir].y0i],
-				x[grad_i[style->fill.gradient.dir].x1i],
-				y[grad_i[style->fill.gradient.dir].y1i]);
-			cairo_pattern_set_extend (cr_pattern, CAIRO_EXTEND_REFLECT);
-			cairo_pattern_add_color_stop_rgba (cr_pattern, 0,
-				GO_COLOR_TO_CAIRO (style->fill.pattern.back));
-			cairo_pattern_add_color_stop_rgba (cr_pattern, 1,
-				GO_COLOR_TO_CAIRO (style->fill.pattern.fore));
-			cairo_set_source (cr, cr_pattern);
-			break;
-
-		case GOG_FILL_STYLE_IMAGE:
-			if (style->fill.image.image == NULL) {
-				cairo_set_source_rgba (cr, 1, 1, 1, 1);
-				break;
-			}
-			cairo_fill_extents (cr, &x[0], &y[0], &x[1], &y[1]);
-			cr_pattern = go_image_create_cairo_pattern (style->fill.image.image);
-			g_object_get (style->fill.image.image, "width", &w, "height", &h, NULL);
-			cairo_pattern_set_extend (cr_pattern, CAIRO_EXTEND_REPEAT);
-			switch (style->fill.image.type) {
-				case GOG_IMAGE_CENTERED:
-					cairo_matrix_init_translate (&cr_matrix,
-								     -(x[1] - x[0] - w) / 2 - x[0],
-								     -(y[1] - y[0] - h) / 2 - y[0]);
-					cairo_pattern_set_matrix (cr_pattern, &cr_matrix);
-					break;
-				case GOG_IMAGE_STRETCHED:
-					cairo_matrix_init_scale (&cr_matrix,
-								 w / (x[1] - x[0]),
-								 h / (y[1] - y[0]));
-					cairo_matrix_translate (&cr_matrix, -x[0], -y[0]);
-					cairo_pattern_set_matrix (cr_pattern, &cr_matrix);
-					break;
-				case GOG_IMAGE_WALLPAPER:
-					break;
-			}
-			cairo_set_source (cr, cr_pattern);
-			break;
+	cr_pattern = gog_style_create_cairo_pattern (style, cr);
+	if (cr_pattern == NULL) {
+		if (!preserve)
+			cairo_new_path (cr);
+		return;
 	}
+	cairo_set_source (cr, cr_pattern);
+	cairo_pattern_destroy (cr_pattern);
 
 	if (preserve)
 		cairo_fill_preserve (cr);
 	else
 		cairo_fill (cr);
-
-	if (cr_pattern != NULL)
-		cairo_pattern_destroy (cr_pattern);
 }
 
 static void
@@ -598,6 +518,7 @@ gog_renderer_stroke_serie (GogRenderer *renderer,
 {
 	GogStyle const *style;
 	GOPathOptions line_options;
+	gboolean is_outline;
 	double width;
 
 	g_return_if_fail (IS_GOG_RENDERER (renderer));
@@ -605,15 +526,18 @@ gog_renderer_stroke_serie (GogRenderer *renderer,
 	g_return_if_fail (IS_GO_PATH (path));
 
         style = renderer->cur_style;
+	is_outline = style->interesting_fields & GOG_STYLE_OUTLINE;
 	line_options = go_path_get_options (path);
 	width = _grc_line_size (renderer,
-			       style->interesting_fields & GOG_STYLE_OUTLINE ?
-			       style->outline.width : style->line.width,
-			       line_options & GO_PATH_OPTIONS_SNAP_WIDTH);
+				is_outline ?  style->outline.width : style->line.width,
+				line_options & GO_PATH_OPTIONS_SNAP_WIDTH);
 
 	if (gog_style_is_line_visible (style)) {
 		path_interpret (renderer, path, width);
-		emit_line (renderer, FALSE, go_path_get_options (path));
+		if (is_outline)
+			emit_outline (renderer, FALSE, go_path_get_options (path));
+		else
+			emit_line (renderer, FALSE, go_path_get_options (path));
 	}
 }
 
@@ -1283,40 +1207,35 @@ gog_renderer_request_update (GogRenderer *renderer)
  * @renderer: a #GogRenderer
  * @w: requested width
  * @h: requested height
- * @zoom: requested zoom
  *
  * Requests a renderer update, only useful for pixbuf based renderer.
  **/
 gboolean
-gog_renderer_update (GogRenderer *rend, double w, double h, double zoom)
+gog_renderer_update (GogRenderer *rend, double w, double h)
 {
 	GogGraph *graph;
 	GogView *view;
 	GogViewAllocation allocation;
-	GOImage *image = NULL;
 	gboolean redraw = TRUE;
 	gboolean size_changed;
-	gboolean create_cairo = rend->cairo == NULL;
 
 	g_return_val_if_fail (IS_GOG_RENDERER (rend), FALSE);
 	g_return_val_if_fail (IS_GOG_VIEW (rend->view), FALSE);
 
 	size_changed = rend->w != w || rend->h != h;
-	if (size_changed && create_cairo) {
-		if (rend->pixbuf != NULL)
-			g_object_unref (rend->pixbuf);
-		rend->pixbuf = NULL;
+	if (size_changed) {
+		if (rend->cairo_surface != NULL) {
+			cairo_surface_destroy (rend->cairo_surface);
+			rend->cairo_surface = NULL;
+		}
+
 		if (w == 0 || h == 0)
 			return FALSE;
+
 		rend->w = w;
 		rend->h = h;
-		rend->pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, rend->w, rend->h);
-		if (rend->pixbuf == NULL) {
-			rend->w = 0;
-			rend->h = 0;
-			g_warning ("GogRendererCairo::cairo_setup: chart is too large");
-			return FALSE;
-		}
+
+		rend->cairo_surface = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, rend->w, rend->h);
 	}
 	if (w == 0 || h == 0)
 		return FALSE;
@@ -1326,20 +1245,15 @@ gog_renderer_update (GogRenderer *rend, double w, double h, double zoom)
 	gog_graph_force_update (graph);
 
 	allocation.x = allocation.y = 0.;
-	allocation.w = w;
-	allocation.h = h;
+	allocation.w = rend->w;
+	allocation.h = rend->h;
 
-	if (create_cairo) {
-		image = go_image_new_from_pixbuf (rend->pixbuf);
-		rend->cairo = go_image_get_cairo (image);
-		rend->is_vector = FALSE;
-	}
+	rend->cairo = cairo_create (rend->cairo_surface);
 
 	if (size_changed) {
-		rend->scale_x = (graph->width >= 1.) ? (w / graph->width) : 1.;
-		rend->scale_y = (graph->height >= 1.) ? (h / graph->height) : 1.;
+		rend->scale_x = (graph->width >= 1.) ? (rend->w / graph->width) : 1.;
+		rend->scale_y = (graph->height >= 1.) ? (rend->h / graph->height) : 1.;
 		rend->scale = MIN (rend->scale_x, rend->scale_y);
-		rend->zoom  = zoom;
 
 		/* make sure we dont try to queue an update while updating */
 		rend->needs_update = TRUE;
@@ -1348,7 +1262,7 @@ gog_renderer_update (GogRenderer *rend, double w, double h, double zoom)
 		gog_renderer_request_update (rend);
 		gog_view_size_allocate (view, &allocation);
 	} else
-		if (w != view->allocation.w || h != view->allocation.h)
+		if (rend->w != view->allocation.w || rend->h != view->allocation.h)
 			gog_view_size_allocate (view, &allocation);
 		else
 			redraw = gog_view_update_sizes (view);
@@ -1357,27 +1271,28 @@ gog_renderer_update (GogRenderer *rend, double w, double h, double zoom)
 	rend->needs_update = FALSE;
 
 	if (redraw) {
-		if (create_cairo) {
-			/* clear if we created it, not otherwise */
+		if (rend->pixbuf) {
+			g_object_unref (rend->pixbuf);
+			rend->pixbuf = NULL;
+		}
+
+		if (!size_changed) {
 			cairo_set_operator (rend->cairo, CAIRO_OPERATOR_CLEAR);
 			cairo_paint (rend->cairo);
 		}
+
 		cairo_set_operator (rend->cairo, CAIRO_OPERATOR_OVER);
 
 		cairo_set_line_join (rend->cairo, CAIRO_LINE_JOIN_ROUND);
 		cairo_set_line_cap (rend->cairo, CAIRO_LINE_CAP_ROUND);
 
+		rend->is_vector = FALSE;
 		gog_view_render	(view, NULL);
-
-		if (create_cairo)
-			go_image_get_pixbuf (image);
 	}
 
-	if (create_cairo) {
-		g_object_unref (image);
-		cairo_destroy (rend->cairo);
-		rend->cairo = NULL;
-	}
+	cairo_destroy (rend->cairo);
+	rend->cairo = NULL;
+
 	return redraw;
 }
 
@@ -1387,14 +1302,37 @@ gog_renderer_update (GogRenderer *rend, double w, double h, double zoom)
  *
  * Returns current pixbuf buffer from a renderer that can render into a pixbuf.
  **/
-GdkPixbuf*
+
+GdkPixbuf *
 gog_renderer_get_pixbuf (GogRenderer *rend)
 {
 	g_return_val_if_fail (IS_GOG_RENDERER (rend), NULL);
 
+	if (rend->cairo_surface == NULL)
+		return NULL;
+
+	if (rend->pixbuf == NULL) {
+		int width = cairo_image_surface_get_width (rend->cairo_surface);
+		int height = cairo_image_surface_get_height (rend->cairo_surface);
+		int rowstride = cairo_image_surface_get_stride (rend->cairo_surface);
+		unsigned char *data = cairo_image_surface_get_data (rend->cairo_surface);
+
+		rend->pixbuf = gdk_pixbuf_new_from_data (data, GDK_COLORSPACE_RGB, TRUE, 8,
+							 width, height, rowstride, NULL, NULL);
+		go_cairo_convert_data_to_pixbuf (data, NULL, width, height, rowstride);
+	}
+
 	return rend->pixbuf;
 }
 
+cairo_surface_t *
+gog_renderer_get_cairo_surface (GogRenderer *rend)
+{
+	g_return_val_if_fail (IS_GOG_RENDERER (rend), NULL);
+
+	return rend->cairo_surface;
+}
+
 static gboolean
 _gsf_gdk_pixbuf_save (const gchar *buf,
 		      gsize count,
@@ -1423,6 +1361,47 @@ _cairo_write_func (void *closure,
 	return result ? CAIRO_STATUS_SUCCESS : CAIRO_STATUS_WRITE_ERROR;
 }
 
+gboolean
+gog_renderer_render_to_cairo (GogRenderer *renderer, cairo_t *cairo, double width, double height)
+{
+	GogViewAllocation allocation;
+	double width_in_pts, height_in_pts;
+
+	g_return_val_if_fail (IS_GOG_RENDERER (renderer), FALSE);
+	g_return_val_if_fail (IS_GOG_VIEW (renderer->view), FALSE);
+	g_return_val_if_fail (IS_GOG_GRAPH (renderer->model), FALSE);
+
+	gog_graph_force_update (renderer->model);
+	gog_graph_get_size (renderer->model, &width_in_pts, &height_in_pts);
+
+	renderer->cairo = cairo;
+	renderer->is_vector = go_cairo_surface_is_vector (cairo_get_target (cairo));
+
+	cairo_set_line_join (renderer->cairo, CAIRO_LINE_JOIN_ROUND);
+	cairo_set_line_cap (renderer->cairo, CAIRO_LINE_CAP_ROUND);
+
+	renderer->w = width;
+	renderer->h = height;
+
+	allocation.x = 0.;
+	allocation.y = 0.;
+	allocation.w = width;
+	allocation.h = height;
+
+	renderer->scale_x = (width_in_pts >= 1.) ? (width / width_in_pts) : 1.;
+	renderer->scale_y = (height_in_pts >= 1.) ? (height / height_in_pts) : 1.;
+	renderer->scale = MIN (renderer->scale_x, renderer->scale_y);
+
+	gog_view_size_allocate (renderer->view, &allocation);
+	gog_view_render	(renderer->view, NULL);
+
+	cairo_show_page (renderer->cairo);
+
+	renderer->cairo = NULL;
+
+	return cairo_status (cairo) == CAIRO_STATUS_SUCCESS;
+}
+
 /**
  * gog_renderer_export_image:
  * @renderer: a #GogRenderer
@@ -1442,10 +1421,10 @@ gboolean
 gog_renderer_export_image (GogRenderer *rend, GOImageFormat format,
 			   GsfOutput *output, double x_dpi, double y_dpi)
 {
-	GogViewAllocation allocation;
 	GOImageFormatInfo const *format_info;
+	cairo_t *cairo;
 	cairo_surface_t *surface = NULL;
-	cairo_status_t status;
+	gboolean status;
 	GdkPixbuf *pixbuf, *output_pixbuf;
 	double width_in_pts, height_in_pts;
 	gboolean result;
@@ -1511,28 +1490,14 @@ gog_renderer_export_image (GogRenderer *rend, GOImageFormat format,
 				default:
 					break;
 			}
-			rend->cairo = cairo_create (surface);
+
+			cairo = cairo_create (surface);
 			cairo_surface_destroy (surface);
-			cairo_set_line_join (rend->cairo, CAIRO_LINE_JOIN_ROUND);
-			cairo_set_line_cap (rend->cairo, CAIRO_LINE_CAP_ROUND);
-			rend->w = width_in_pts;
-			rend->h = height_in_pts;
-			rend->is_vector = TRUE;
+			status = gog_renderer_render_to_cairo (rend, cairo, width_in_pts, height_in_pts);
+			cairo_destroy (cairo);
 
-			allocation.x = 0.;
-			allocation.y = 0.;
-			allocation.w = width_in_pts;
-			allocation.h = height_in_pts;
-			gog_view_size_allocate (rend->view, &allocation);
-			gog_view_render	(rend->view, NULL);
+			return status;
 
-			cairo_show_page (rend->cairo);
-			status = cairo_status (rend->cairo);
-
-			cairo_destroy (rend->cairo);
-			rend->cairo = NULL;
-
-			return status == CAIRO_STATUS_SUCCESS;
 			break;
 		default:
 			format_info = go_image_get_format_info (format);
@@ -1541,9 +1506,7 @@ gog_renderer_export_image (GogRenderer *rend, GOImageFormat format,
 				return FALSE;
 			}
 
-			gog_renderer_update (rend,
-					     width_in_pts * x_dpi / 72.0,
-					     height_in_pts * y_dpi / 72.0, 1.0);
+			gog_renderer_update (rend, width_in_pts * x_dpi / 72.0, height_in_pts * y_dpi / 72.0);
 			pixbuf = gog_renderer_get_pixbuf (rend);
 			if (pixbuf == NULL)
 				return FALSE;
@@ -1555,7 +1518,6 @@ gog_renderer_export_image (GogRenderer *rend, GOImageFormat format,
 										   GDK_INTERP_NEAREST,
 										   255, 256, 0xffffffff,
 										   0xffffffff);
-
 			else
 				output_pixbuf = pixbuf;
 			result = gdk_pixbuf_save_to_callback (output_pixbuf,
@@ -1577,6 +1539,7 @@ gog_renderer_export_image (GogRenderer *rend, GOImageFormat format,
  *
  * returns the hairline width in pts.
  **/
+
 double
 gog_renderer_get_hairline_width_pts (GogRenderer const *rend)
 {
@@ -1590,30 +1553,14 @@ gog_renderer_get_hairline_width_pts (GogRenderer const *rend)
 }
 
 /**
- * gog_renderer_new_for_pixbuf:
+ * gog_renderer_new:
  * @graph : graph model
  *
  * Creates a new renderer which can render into a pixbuf, and sets
  * @graph as its model.
  **/
 GogRenderer*
-gog_renderer_new_for_pixbuf (GogGraph *graph)
-{
-	return g_object_new (GOG_RENDERER_TYPE, "model", graph, NULL);
-}
-
-/**
- * gog_renderer_new_for_format:
- * @graph: a #GogGraph
- * @format: image format
- * 
- * Creates a new #GogRenderer which is capable of export to @format.
- *
- * returns: a new #GogRenderer.
- **/
-
-GogRenderer *
-gog_renderer_new_for_format (GogGraph *graph, GOImageFormat format)
+gog_renderer_new (GogGraph *graph)
 {
 	return g_object_new (GOG_RENDERER_TYPE, "model", graph, NULL);
 }
@@ -1631,7 +1578,7 @@ static void
 gog_renderer_init (GogRenderer *rend)
 {
 	rend->cairo = NULL;
-	rend->pixbuf = NULL;
+	rend->cairo_surface = NULL;
 	rend->marker_surface = NULL;
 	rend->w = rend->h = 0;
 	rend->is_vector = FALSE;
@@ -1642,13 +1589,14 @@ gog_renderer_init (GogRenderer *rend)
 	rend->needs_update = FALSE;
 	rend->cur_style    = NULL;
 	rend->style_stack  = NULL;
-	rend->zoom = rend->scale = rend->scale_x = rend->scale_y = 1.;
 	rend->font_watcher = g_cclosure_new_swap (G_CALLBACK (_cb_font_removed),
 		rend, NULL);
 	go_font_cache_register (rend->font_watcher);
 
 	rend->grip_style = NULL;
 	rend->selection_style = NULL;
+
+	rend->pixbuf = NULL;
 }
 
 static void
@@ -1656,14 +1604,16 @@ gog_renderer_finalize (GObject *obj)
 {
 	GogRenderer *rend = GOG_RENDERER (obj);
 
-	if (rend->cairo != NULL){
-		cairo_destroy (rend->cairo);
-		rend->cairo = NULL;
-	}
 	if (rend->pixbuf != NULL) {
 		g_object_unref (rend->pixbuf);
 		rend->pixbuf = NULL;
 	}
+
+	if (rend->cairo_surface != NULL) {
+		cairo_surface_destroy (rend->cairo_surface);
+		rend->cairo_surface = NULL;
+	}
+
 	_free_marker_data (rend);
 
 	go_line_dash_sequence_free (rend->line_dash);
@@ -1723,22 +1673,6 @@ gog_renderer_set_property (GObject *obj, guint param_id,
 		gog_renderer_request_update (rend);
 		break;
 
-	case RENDERER_PROP_ZOOM:
-		rend->zoom = g_value_get_double (value);
-		break;
-
-	case RENDERER_PROP_CAIRO:
-		if (rend->cairo)
-			cairo_destroy (rend->cairo);
-		rend->cairo = g_value_get_pointer (value);
-		if (rend->cairo)
-			cairo_reference (rend->cairo);
-		break;
-
-	case RENDERER_PROP_IS_VECTOR:
-		rend->is_vector = g_value_get_boolean (value);
-		break;
-
 	default: G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
 		 return; /* NOTE : RETURN */
 	}
@@ -1757,15 +1691,6 @@ gog_renderer_get_property (GObject *obj, guint param_id,
 	case RENDERER_PROP_VIEW:
 		g_value_set_object (value, rend->view);
 		break;
-	case RENDERER_PROP_ZOOM:
-		g_value_set_double (value, rend->zoom);
-		break;
-	case RENDERER_PROP_CAIRO:
-		g_value_set_pointer (value, rend->cairo);
-		break;
-	case RENDERER_PROP_IS_VECTOR:
-		g_value_set_boolean (value, rend->is_vector);
-		break;
 	default: G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
 		 break;
 	}
@@ -1793,23 +1718,6 @@ gog_renderer_class_init (GogRendererClass *renderer_klass)
 			_("the GogView this renderer is displaying"),
 			GOG_VIEW_TYPE,
 			GSF_PARAM_STATIC | G_PARAM_READABLE));
-	g_object_class_install_property (gobject_klass, RENDERER_PROP_ZOOM,
-		g_param_spec_double ("zoom",
-			_("Zoom Height Pts"),
-			_("Global scale factor"),
-			1., G_MAXDOUBLE, 1.,
-			GSF_PARAM_STATIC | G_PARAM_READWRITE));
-	g_object_class_install_property (gobject_klass, RENDERER_PROP_CAIRO,
-		g_param_spec_pointer ("cairo",
-			_("Cairo"),
-			_("The cairo_t* this renderer uses"),
-			GSF_PARAM_STATIC | G_PARAM_READWRITE));
-	g_object_class_install_property (gobject_klass, RENDERER_PROP_IS_VECTOR,
-		g_param_spec_boolean ("is-vector",
-			_("Is vector"),
-			_("Tells if the cairo surface is vectorial or raster"),
-			FALSE,
-			GSF_PARAM_STATIC | G_PARAM_READWRITE));
 
 	renderer_signals [RENDERER_SIGNAL_REQUEST_UPDATE] = g_signal_new ("request-update",
 		G_TYPE_FROM_CLASS (renderer_klass),
