@@ -20,36 +20,11 @@
  */
 
 #include <goffice/goffice-config.h>
-
 #include <goffice/utils/go-image.h>
-
+#include <goffice/gtk/goffice-gtk.h>
 #include "go-palette.h"
-
-#include <gtk/gtkalignment.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkarrow.h>
-#include <gtk/gtkcelllayout.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkcellview.h>
-#include <gtk/gtkcombobox.h>
-#include <gtk/gtkdrawingarea.h>
-#include <gtk/gtkframe.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtkiconview.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkliststore.h>
-#include <gtk/gtkmenu.h>
-#include <gtk/gtkmenuitem.h>
-#include <gtk/gtkseparatormenuitem.h>
-#include <gtk/gtktogglebutton.h>
-#include <gtk/gtktooltips.h>
-#include <gtk/gtktreemodel.h>
-#include <gtk/gtktreeview.h>
-#include <gtk/gtkvseparator.h>
-#include <gtk/gtkversion.h>
-
+#include <gtk/gtk.h>
 #include <glib/gi18n-lib.h>
-
 #include <gdk/gdkkeysyms.h>
 
 #include <math.h>
@@ -68,8 +43,6 @@ static GtkWidget       *go_palette_menu_item_new (GOPalette *palette, int index)
 static void 		cb_automatic_activate 	 (GtkWidget *item, GOPalette *palette);
 static void 		cb_custom_activate 	 (GtkWidget *item, GOPalette *palette);
 
-#define GO_PALETTE_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), GO_TYPE_PALETTE, GOPalettePrivate))
-
 struct _GOPalettePrivate {
 	int		 n_swatches;
 	int 		 n_columns;
@@ -77,7 +50,7 @@ struct _GOPalettePrivate {
 	int		 swatch_width;
 	int		 swatch_height;
 
-	GOPaletteSwatchRenderCallback 	swatch_render; 
+	GOPaletteSwatchRenderCallback 	swatch_render;
 	GOPaletteSwatchTooltipCallback 	get_tooltip;
 
 	gpointer 	 data;
@@ -88,13 +61,11 @@ struct _GOPalettePrivate {
 	GtkWidget	*automatic_separator;
 	char		*automatic_label;
 	int		 automatic_index;
-	
+
 	gboolean	 show_custom;
 	GtkWidget	*custom;
 	GtkWidget	*custom_separator;
 	char		*custom_label;
-
-	GtkTooltips	*tooltips;
 };
 
 G_DEFINE_TYPE (GOPalette, go_palette, GTK_TYPE_MENU)
@@ -106,7 +77,7 @@ go_palette_init (GOPalette *palette)
 	PangoLayout *layout;
 	PangoRectangle rect;
 
-	priv = GO_PALETTE_GET_PRIVATE (palette);
+	priv = G_TYPE_INSTANCE_GET_PRIVATE (palette, GO_TYPE_PALETTE, GOPalettePrivate);
 
 	palette->priv = priv;
 
@@ -127,21 +98,13 @@ go_palette_init (GOPalette *palette)
 	priv->show_custom = FALSE;
 
 	priv->automatic_index = 0;
-	
+
 	layout = gtk_widget_create_pango_layout (GTK_WIDGET (palette), "A");
 	pango_layout_get_pixel_extents (layout, NULL, &rect);
 	g_object_unref (layout);
 
 	priv->swatch_height = rect.height + 2;
 	priv->swatch_width = priv->swatch_height;
-
-	priv->tooltips = gtk_tooltips_new ();
-#if GLIB_CHECK_VERSION(2,10,0) && GTK_CHECK_VERSION(2,8,14)
-	g_object_ref_sink (priv->tooltips);
-#else
-	g_object_ref (priv->tooltips);
-	gtk_object_sink (GTK_OBJECT (priv->tooltips));
-#endif
 }
 
 static void
@@ -230,9 +193,8 @@ go_palette_finalize (GObject *object)
 {
 	GOPalettePrivate *priv;
 
-	priv = GO_PALETTE_GET_PRIVATE (object);
+	priv = GO_PALETTE(object)->priv;
 
-	g_object_unref (priv->tooltips);
 	if (priv->data && priv->destroy)
 		(priv->destroy) (priv->data);
 	g_free (priv->automatic_label);
@@ -248,9 +210,9 @@ cb_swatch_expose (GtkWidget *swatch, GdkEventExpose *event, GOPalette *palette)
 		cairo_t *cr;
 		GdkRectangle area;
 		int index;
-		
+
 #if GTK_CHECK_VERSION(2,8,0)
-		
+
 		cr = gdk_cairo_create (swatch->window);
 
 		area.x = 0;
@@ -265,8 +227,8 @@ cb_swatch_expose (GtkWidget *swatch, GdkEventExpose *event, GOPalette *palette)
 		cairo_destroy (cr);
 
 #else /* if GTK < 2.8.0 */
-	
-#warning [GOPalette:cb_swatch_expose] Use of old version of gtk (<2.8.0)	
+
+#warning [GOPalette:cb_swatch_expose] Use of old version of gtk (<2.8.0)
 
 		GdkPixbuf *pixbuf;
 		GOImage *image;
@@ -275,18 +237,18 @@ cb_swatch_expose (GtkWidget *swatch, GdkEventExpose *event, GOPalette *palette)
 		area.y = 0;
 		area.width = swatch->allocation.width;
 		area.height = swatch->allocation.height;
-		
-	       	pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 
+
+		pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8,
 					 area.width, area.height);
-	       	image = go_image_new_from_pixbuf (pixbuf);
+		image = go_image_new_from_pixbuf (pixbuf);
 		g_object_unref (pixbuf);
-		
+
 		cr = go_image_get_cairo (image);
-		
+
 		index = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (swatch), "index"));
 
 		(palette->priv->swatch_render) (cr, &area, index, palette->priv->data);
-		
+
 		cairo_destroy (cr);
 		pixbuf = go_image_get_pixbuf (image);
 
@@ -324,7 +286,7 @@ go_palette_menu_item_new (GOPalette *palette, int index)
 		char const *tip;
 
 		tip = priv->get_tooltip (index, priv->data);
-		gtk_tooltips_set_tip (palette->priv->tooltips, item, tip, NULL);
+		go_widget_set_tooltip_text (item, tip);
 	}
 	
 	g_signal_connect (item, "activate", G_CALLBACK (cb_menu_item_activate), palette); 
@@ -364,7 +326,6 @@ go_palette_new (int n_swatches,
 		GOPaletteSwatchTooltipCallback get_tooltip,
 		gpointer data,
 		GDestroyNotify destroy)
-			
 {
 	GOPalettePrivate *priv;
 	GtkWidget *palette;
@@ -464,7 +425,9 @@ GtkWidget *
 go_palette_swatch_new (GOPalette *palette, int index)
 {
 	GtkWidget *swatch;
-	
+
+	g_return_val_if_fail (GO_IS_PALETTE (palette), NULL);
+
 	swatch = gtk_drawing_area_new ();
 
 	g_object_set_data (G_OBJECT (swatch), "index", GINT_TO_POINTER (index));
@@ -489,6 +452,8 @@ go_palette_swatch_new (GOPalette *palette, int index)
 int
 go_palette_get_n_swatches (GOPalette *palette)
 {
+	g_return_val_if_fail (GO_IS_PALETTE (palette), 0);
+
 	return palette->priv->n_swatches;
 }
 
