@@ -34,7 +34,7 @@
 #include <goffice/utils/go-color.h>
 #include <goffice/utils/go-marker.h>
 #include <goffice/utils/go-format.h>
-#include <goffice/utils/go-math.h>
+#include <goffice/math/go-math.h>
 #include <goffice/utils/go-line.h>
 #include <goffice/app/module-plugin-defs.h>
 
